@@ -69,7 +69,7 @@ get_predictions_MixMod <- function(model, data_grid, ci.lvl, linv, type, terms,
 
 
   if (model_info$is_zero_inflated && prtype == "mean_subject") {
-    add.args <- lapply(match.call(expand.dots = F)$`...`, function(x) x)
+    add.args <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
 
     if ("nsim" %in% names(add.args))
       nsim <- eval(add.args[["nsim"]])
