@@ -1,10 +1,13 @@
 #' @importFrom stats qnorm predict
-get_predictions_generic2 <- function(model, fitfram, ci.lvl, linv, type, model.class, typical, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...) {
+get_predictions_generic2 <- function(model, fitfram, ci.lvl, linv, type, model_class, value_adjustment, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...) {
   # get prediction type.
   pt <- switch(
-    model.class,
-    "betareg" = "link",
-    "vgam" = "link",
+    model_class,
+    "betareg" = ,
+    "vgam"    = ,
+    "feglm"   = ,
+    "glmx"    = ,
+    "fixest"  = "link",
     "response"
   )
 
@@ -30,13 +33,13 @@ get_predictions_generic2 <- function(model, fitfram, ci.lvl, linv, type, model.c
 
   # get standard errors from variance-covariance matrix
   se.pred <-
-    .get_se_from_vcov(
+    .standard_error_predictions(
       model = model,
-      fitfram = fitfram,
-      typical = typical,
+      prediction_data = fitfram,
+      value_adjustment = value_adjustment,
       type = type,
       terms = terms,
-      model.class = model.class,
+      model_class = model_class,
       vcov.fun = vcov.fun,
       vcov.type = vcov.type,
       vcov.args = vcov.args,
@@ -47,7 +50,7 @@ get_predictions_generic2 <- function(model, fitfram, ci.lvl, linv, type, model.c
 
   if (!is.null(se.pred) && isTRUE(se)) {
     se.fit <- se.pred$se.fit
-    fitfram <- se.pred$fitfram
+    fitfram <- se.pred$prediction_data
 
     # CI
     fitfram$conf.low <- linv(fitfram$predicted - stats::qnorm(ci) * se.fit)
