@@ -66,7 +66,7 @@ ggeffect_helper <- function(model, terms, ci.lvl, ...) {
   # check whether we have an argument "transformation" for effects()-function
   # in this case, we need another default title, since we have
   # non-transformed effects
-  additional_dot_args <- lapply(match.call(expand.dots = F)$`...`, function(x) x)
+  additional_dot_args <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
   # check whether we have a "transformation" argument
   t.add <- which(names(additional_dot_args) == "transformation")
   # if we have a "transformation" argument, and it's NULL,
@@ -268,6 +268,10 @@ ggeffect_helper <- function(model, terms, ci.lvl, ...) {
   # convert to data frame
   result <- as.data.frame(tmp, stringsAsFactors = FALSE)
 
+  if (is.null(result$group)) {
+    result$group <- as.factor(1)
+  }
+
   if (length(terms) > 1) {
     attr(result, "continuous.group") <- is.numeric(original_model_frame[[terms[2]]]) & is.null(attr(original_model_frame[[terms[2]]], "labels"))
   } else {
