@@ -46,28 +46,25 @@
   # model formula, but *not* used back-transformation "exp". Tell user
   # so she's aware of the problem
 
-  tryCatch(
+  offset_log_term <- tryCatch(
     {
+      olt <- NULL
       if (!inherits(model, "brmsfit") && show_pretty_message && .has_log(model)) {
-        check1 <- .get_offset_log_terms(model)
-        check2 <- .get_log_terms(model)
-
+        any_offset_log_term <- .get_offset_log_terms(model)
         # check if we have offset() in formula, with transformed variable
-        if (any(check1)) {
+        if (any(any_offset_log_term)) {
           clean.term <- insight::find_predictors(model, effects = "all", component = "all", flatten = FALSE)
-          clean.term <- unlist(clean.term[c("conditional", "random", "instruments")])[check1]
+          clean.term <- unlist(clean.term[c("conditional", "random", "instruments")])[any_offset_log_term]
 
           # try to back-transform
           offset_function <- .get_offset_transformation(model)
           if (identical(offset_function, "log")) {
-            model_frame[[clean.term]] <- exp(model_frame[[clean.term]])
-          } else {
-            insight::print_color(sprintf("Model uses a transformed offset term. Predictions may not be correct. Please apply transformation of offset term to the data before fitting the model and use 'offset=%s' in the model formula.\n", clean.term), "red")
+            warning(sprintf("Model uses a transformed offset term. Predictions may not be correct. Please apply transformation of offset term to the data before fitting the model and use 'offset(%s)' in the model formula.\n", clean.term), call. = FALSE)
+            olt <- clean.term
           }
-
-          check2 <- check2 & !check1
         }
       }
+      olt
     },
     error = function(x) { NULL },
     warning = function(x) { NULL },
@@ -146,6 +143,11 @@
     model_predictors <- unique(c(insight::find_response(model), model_predictors, model@call_info$id, model@call_info$wave))
   }
 
+  # check if offset term is in model frame
+  if (!is.null(offset_term) && !(offset_term %in% colnames(model_frame))) {
+    model_frame <- .add_offset_to_mf(model, model_frame, offset_term)
+  }
+
   # get count of terms, and number of columns
   n_predictors <- length(model_predictors)
 
@@ -220,7 +222,7 @@
     constant_values <- lapply(model_predictors, function(x) {
       pred <- model_frame[[x]]
       if (!is.factor(pred) && !x %in% random_effect_terms) {
-        .typical_value(pred, fun = value_adjustment, weights = w, predictor = x, log_terms = .which_log_terms(model))
+        .typical_value(pred, fun = value_adjustment, weights = w, predictor = x, log_terms = .which_log_terms(model), emmeans.only = emmeans.only)
       }
     })
     names(constant_values) <- model_predictors
@@ -334,7 +336,7 @@
 
 
   # create data frame with all unqiue combinations
-  dat <- as.data.frame(expand.grid(focal_terms))
+  dat <- as.data.frame(expand.grid(focal_terms, stringsAsFactors = TRUE))
 
 
   # we have to check type consistency. If user specified certain value
@@ -439,3 +441,44 @@
 
   datlist
 }
+
+
+
+.add_offset_to_mf <- function(x, model_frame, offset_term) {
+  # first try, parent frame
+  dat <- tryCatch(
+    {
+      eval(x$call$data, envir = parent.frame())
+    },
+    error = function(e) {
+      NULL
+    }
+  )
+
+  if (is.null(dat)) {
+    # second try, global env
+    dat <- tryCatch(
+      {
+        eval(x$call$data, envir = globalenv())
+      },
+      error = function(e) {
+        NULL
+      }
+    )
+  }
+
+
+  if (!is.null(dat) && .obj_has_name(x$call, "subset")) {
+    dat <- subset(dat, subset = eval(x$call$subset))
+  }
+
+  tryCatch(
+    {
+      dat <- stats::na.omit(dat[c(intersect(colnames(model_frame), colnames(dat)), offset_term)])
+      cbind(model_frame, dat[offset_term])
+    },
+    error = function(e) {
+      model_frame
+    }
+  )
+}
