@@ -1,6 +1,12 @@
 ## ----set-options, echo = FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 knitr::opts_chunk$set(collapse = TRUE, comment = "#>", dev = "png", fig.width = 7, fig.height = 4, message = FALSE, warning = FALSE)
 options(width = 800)
+if (!requireNamespace("ggplot2", quietly = TRUE) ||
+    !requireNamespace("lme4", quietly = TRUE) ||
+    !requireNamespace("survival", quietly = TRUE) ||
+    !requireNamespace("sjmisc", quietly = TRUE)) {
+  knitr::opts_chunk$set(eval = FALSE)
+}
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 library(ggeffects)
@@ -56,43 +62,34 @@ dat <- ggpredict(fit, terms = "c172code")
 plot(dat, ci.style = "dot")
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-if (requireNamespace("lme4")) {
-  m <- glm(
-    cbind(incidence, size - incidence) ~ period, 
-    family = binomial, 
-    data = lme4::cbpp
-  )
-  
-  dat <- ggpredict(m, "period")
-  
-  # normal plot, asymmetrical error bars
-  plot(dat)
-}
+library("lme4")
+m <- glm(
+  cbind(incidence, size - incidence) ~ period, 
+  family = binomial, 
+  data = lme4::cbpp
+)
+
+dat <- ggpredict(m, "period")
+
+# normal plot, asymmetrical error bars
+plot(dat)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-if (requireNamespace("lme4")) {
-  # plot with log-transformed y-axis
-  plot(dat, log.y = TRUE)
-}
+# plot with log-transformed y-axis
+plot(dat, log.y = TRUE)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-if (requireNamespace("lme4")) {
-  # plot with log-transformed y-axis, modify breaks
-  plot(
-    dat, log.y = TRUE, 
-    breaks = c(.05, .1, .15, .2, .25, .3),
-    limits = c(.01, .3)
-  )
-}
+# plot with log-transformed y-axis, modify breaks
+plot(
+  dat, log.y = TRUE, 
+  breaks = c(.05, .1, .15, .2, .25, .3),
+  limits = c(.01, .3)
+)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-data("lung", package = "survival")
-# remove category 3 (outlier, not nice in the plot)
-lung <- subset(lung, subset = ph.ecog %in% 0:2)
-lung$sex <- factor(lung$sex, labels = c("male", "female"))
-lung$ph.ecog <- factor(lung$ph.ecog, labels = c("good", "ok", "limited"))
-
-m <- survival::coxph(survival::Surv(time, status) ~ sex + age + ph.ecog, data = lung)
+library(survival)
+data("lung")
+m <- coxph(Surv(time, status) ~ sex + age + ph.ecog, data = lung)
 
 # predicted risk-scores
 pr <- ggpredict(m, c("sex", "ph.ecog"))
@@ -100,12 +97,12 @@ plot(pr)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # probability of survival
-pr <- ggpredict(m, c("sex", "ph.ecog"), type = "surv")
+pr <- ggpredict(m, c("sex", "ph.ecog"), type = "survival")
 plot(pr)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # cumulative hazards
-pr <- ggpredict(m, c("sex", "ph.ecog"), type = "cumhaz")
+pr <- ggpredict(m, c("sex", "ph.ecog"), type = "cumulative_hazard")
 plot(pr)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
