@@ -1,6 +1,6 @@
 .runThisTest <- Sys.getenv("RunAllggeffectsTests") == "yes"
 
-if (.runThisTest && Sys.getenv("USER") != "travis") {
+if (.runThisTest) {
   if (require("testthat") && require("ggeffects") && require("MCMCglmm")) {
     set.seed(123)
     data(PlodiaPO)
@@ -16,7 +16,7 @@ if (.runThisTest && Sys.getenv("USER") != "travis") {
 
     test_that("ggpredict", {
       p <- ggpredict(m1, "plate")
-      expect_equal(p$predicted[1], 1.056156, tolerance = 1e-4)
+      expect_equal(p$predicted[1], 1.055517, tolerance = 1e-3)
     })
   }
 }
